==> huaweicloudsdkeg-3.1.135-py2.py3-none-any.whl: huaweicloudsdkeg/v1/model/channel_create_req_principal.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ChannelCreateReqPrincipal:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'iam': 'list[str]'
    }

    attribute_map = {
        'iam': 'IAM'
    }

    def __init__(self, iam=None):
        """ChannelCreateReqPrincipal

        The model defined in huaweicloud sdk

        :param iam: 
        :type iam: list[str]
        """
        
        

        self._iam = None
        self.discriminator = None

        if iam is not None:
            self.iam = iam

    @property
    def iam(self):
        """Gets the iam of this ChannelCreateReqPrincipal.

        :return: The iam of this ChannelCreateReqPrincipal.
        :rtype: list[str]
        """
        return self._iam

    @iam.setter
    def iam(self, iam):
        """Sets the iam of this ChannelCreateReqPrincipal.

        :param iam: The iam of this ChannelCreateReqPrincipal.
        :type iam: list[str]
        """
        self._iam = iam

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChannelCreateReqPrincipal):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeg-3.1.150-py2.py3-none-any.whl: huaweicloudsdkeg/v1/model/channel_create_req_principal.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ChannelCreateReqPrincipal:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'iam': 'list[str]'
    }

    attribute_map = {
        'iam': 'IAM'
    }

    def __init__(self, iam=None):
        r"""ChannelCreateReqPrincipal

        The model defined in huaweicloud sdk

        :param iam: 
        :type iam: list[str]
        """
        
        

        self._iam = None
        self.discriminator = None

        if iam is not None:
            self.iam = iam

    @property
    def iam(self):
        r"""Gets the iam of this ChannelCreateReqPrincipal.

        :return: The iam of this ChannelCreateReqPrincipal.
        :rtype: list[str]
        """
        return self._iam

    @iam.setter
    def iam(self, iam):
        r"""Sets the iam of this ChannelCreateReqPrincipal.

        :param iam: The iam of this ChannelCreateReqPrincipal.
        :type iam: list[str]
        """
        self._iam = iam

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChannelCreateReqPrincipal):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
